==> jc-1.4.0.tar.gz: java/security/cert/CRL.h <==
// public abstract class java.security.cert.CRL

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 968d6f530411e76e java_security_cert_CRL

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CRL_H_
#define _JC_java_security_cert_CRL_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_cert_Certificate$object;

// Typedefs
typedef struct _jc_java_security_cert_CRL$sub_refs	_jc_java_security_cert_CRL$sub_refs;
typedef struct _jc_java_security_cert_CRL$sub_nonrefs	_jc_java_security_cert_CRL$sub_nonrefs;
typedef struct _jc_java_security_cert_CRL$refs	_jc_java_security_cert_CRL$refs;
typedef struct _jc_java_security_cert_CRL$nonrefs	_jc_java_security_cert_CRL$nonrefs;
typedef struct _jc_java_security_cert_CRL$object	_jc_java_security_cert_CRL$object;

typedef const struct _jc_java_security_cert_CRL$vmethods	_jc_java_security_cert_CRL$vmethods;
typedef const struct _jc_java_security_cert_CRL$vtable	_jc_java_security_cert_CRL$vtable;
typedef const struct _jc_java_security_cert_CRL$vtype	_jc_java_security_cert_CRL$vtype;

// Constructors
extern void _jc_java_security_cert_CRL$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CRL$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6(_jc_env *, struct _jc_java_security_cert_CRL$object *);
extern jboolean _jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209(_jc_env *, struct _jc_java_security_cert_CRL$object *, struct _jc_java_security_cert_Certificate$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_CRL$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CRL$method_info$getType$1756580bdd350fe6;
extern _jc_method _jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209;
extern _jc_method _jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_CRL$vmethods {
	struct _jc_java_lang_String$object	*(*getType$1756580bdd350fe6)(_jc_env *, struct _jc_java_security_cert_CRL$object *);
	jboolean	(*isRevoked$9ba1c89363dd6209)(_jc_env *, struct _jc_java_security_cert_CRL$object *, struct _jc_java_security_cert_Certificate$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_CRL$object *);
};

// Vtable
struct _jc_java_security_cert_CRL$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CRL$vmethods	java_security_cert_CRL;
};

// Vtype
struct _jc_java_security_cert_CRL$vtype {
	_jc_type			type;
	_jc_java_security_cert_CRL$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CRL$sub_refs {
	struct _jc_java_lang_String$object	*type;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CRL$refs {
    _jc_java_security_cert_CRL$sub_refs	java_security_cert_CRL;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CRL$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CRL$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CRL$sub_nonrefs	java_security_cert_CRL;
};

// Object instance structure
struct _jc_java_security_cert_CRL$object {
	_jc_java_security_cert_CRL$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CRL$vtype	*vtype;
	_jc_java_security_cert_CRL$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CRL$vtype _jc_java_security_cert_CRL$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CRL, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CRL$class_object;

#endif	/* _JC_java_security_cert_CRL_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CRL.h <==
// public abstract class java.security.cert.CRL

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 968d6f530411e76e java_security_cert_CRL

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CRL_H_
#define _JC_java_security_cert_CRL_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_cert_Certificate$object;

// Typedefs
typedef struct _jc_java_security_cert_CRL$sub_refs	_jc_java_security_cert_CRL$sub_refs;
typedef struct _jc_java_security_cert_CRL$sub_nonrefs	_jc_java_security_cert_CRL$sub_nonrefs;
typedef struct _jc_java_security_cert_CRL$refs	_jc_java_security_cert_CRL$refs;
typedef struct _jc_java_security_cert_CRL$nonrefs	_jc_java_security_cert_CRL$nonrefs;
typedef struct _jc_java_security_cert_CRL$object	_jc_java_security_cert_CRL$object;

typedef const struct _jc_java_security_cert_CRL$vmethods	_jc_java_security_cert_CRL$vmethods;
typedef const struct _jc_java_security_cert_CRL$vtable	_jc_java_security_cert_CRL$vtable;
typedef const struct _jc_java_security_cert_CRL$vtype	_jc_java_security_cert_CRL$vtype;

// Constructors
extern void _jc_java_security_cert_CRL$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CRL$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6(_jc_env *, struct _jc_java_security_cert_CRL$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209(_jc_env *, struct _jc_java_security_cert_CRL$object *, struct _jc_java_security_cert_Certificate$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_CRL$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CRL$method_info$getType$1756580bdd350fe6;
extern _jc_method _jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209;
extern _jc_method _jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_CRL$vmethods {
	struct _jc_java_lang_String$object	*(*getType$1756580bdd350fe6)(_jc_env *, struct _jc_java_security_cert_CRL$object *) _JC_JCNI_ATTR;
	jboolean	(*isRevoked$9ba1c89363dd6209)(_jc_env *, struct _jc_java_security_cert_CRL$object *, struct _jc_java_security_cert_Certificate$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_CRL$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CRL$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CRL$vmethods	java_security_cert_CRL;
};

// Vtype
struct _jc_java_security_cert_CRL$vtype {
	_jc_type			type;
	_jc_java_security_cert_CRL$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CRL$sub_refs {
	struct _jc_java_lang_String$object	*type;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CRL$refs {
    _jc_java_security_cert_CRL$sub_refs	java_security_cert_CRL;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CRL$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CRL$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CRL$sub_nonrefs	java_security_cert_CRL;
};

// Object instance structure
struct _jc_java_security_cert_CRL$object {
	_jc_java_security_cert_CRL$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CRL$vtype	*vtype;
	_jc_java_security_cert_CRL$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CRL$vtype _jc_java_security_cert_CRL$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CRL, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CRL$class_object;

#endif	/* _JC_java_security_cert_CRL_H_ */
